@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2013 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2014 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -178,7 +178,7 @@ class gPodderSyncUI(object):
                 self.commit_changes_to_database()
                 for current_channel in self.channels:
                     #only sync those channels marked for syncing
-                    if (current_channel.sync_to_mp3_player and self._config.device_sync.playlists.create):
+                    if (self._config.device_sync.device_type=='filesystem' and current_channel.sync_to_mp3_player and self._config.device_sync.playlists.create):
 
                         #get playlist object
                         playlist=gPodderDevicePlaylist(self._config,
@@ -195,7 +195,7 @@ class gPodderSyncUI(object):
                 #enable updating of UI
                 self.enable_download_list_update()
                 
-                if self._config.device_sync.playlists.create:                 
+                if (self._config.device_sync.device_type=='filesystem' and self._config.device_sync.playlists.create):                 
                     title = _('Update successful')
                     message = _('The playlist on your MP3 player has been updated.')
                     self.notification(message, title, widget=self.preferences_widget)
